instrumenttools.transpose_from_fingered_pitch_to_sounding_pitch
===============================================================

.. autofunction:: abjad.tools.instrumenttools.transpose_from_fingered_pitch_to_sounding_pitch.transpose_from_fingered_pitch_to_sounding_pitch
   :noindex:
